@@ -250,6 +250,7 @@ class ServerlessClamscan(
         efs_encryption: typing.Optional[builtins.bool] = None,
         on_error: typing.Optional[monocdk.aws_lambda.IDestination] = None,
         on_result: typing.Optional[monocdk.aws_lambda.IDestination] = None,
+        reserved_concurrency: typing.Optional[jsii.Number] = None,
     ) -> None:
         '''Creates a ServerlessClamscan construct.
 
@@ -260,6 +261,7 @@ class ServerlessClamscan(
         :param efs_encryption: Whether or not to enable encryption on EFS filesystem (Default: enabled).
         :param on_error: The Lambda Destination for files that fail to scan and are marked 'ERROR' or stuck 'IN PROGRESS' due to a Lambda timeout (Default: Creates and publishes to a new SQS queue if unspecified).
         :param on_result: The Lambda Destination for files marked 'CLEAN' or 'INFECTED' based on the ClamAV Virus scan or 'N/A' for scans triggered by S3 folder creation events marked (Default: Creates and publishes to a new Event Bridge Bus if unspecified).
+        :param reserved_concurrency: Optionally set a reserved concurrency for the virus scanning Lambda.
         '''
         props = ServerlessClamscanProps(
             buckets=buckets,
@@ -267,6 +269,7 @@ class ServerlessClamscan(
             efs_encryption=efs_encryption,
             on_error=on_error,
             on_result=on_result,
+            reserved_concurrency=reserved_concurrency,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -389,6 +392,7 @@ class ServerlessClamscanLoggingProps:
         "efs_encryption": "efsEncryption",
         "on_error": "onError",
         "on_result": "onResult",
+        "reserved_concurrency": "reservedConcurrency",
     },
 )
 class ServerlessClamscanProps:
@@ -400,6 +404,7 @@ class ServerlessClamscanProps:
         efs_encryption: typing.Optional[builtins.bool] = None,
         on_error: typing.Optional[monocdk.aws_lambda.IDestination] = None,
         on_result: typing.Optional[monocdk.aws_lambda.IDestination] = None,
+        reserved_concurrency: typing.Optional[jsii.Number] = None,
     ) -> None:
         '''Interface for creating a ServerlessClamscan.
 
@@ -408,6 +413,7 @@ class ServerlessClamscanProps:
         :param efs_encryption: Whether or not to enable encryption on EFS filesystem (Default: enabled).
         :param on_error: The Lambda Destination for files that fail to scan and are marked 'ERROR' or stuck 'IN PROGRESS' due to a Lambda timeout (Default: Creates and publishes to a new SQS queue if unspecified).
         :param on_result: The Lambda Destination for files marked 'CLEAN' or 'INFECTED' based on the ClamAV Virus scan or 'N/A' for scans triggered by S3 folder creation events marked (Default: Creates and publishes to a new Event Bridge Bus if unspecified).
+        :param reserved_concurrency: Optionally set a reserved concurrency for the virus scanning Lambda.
         '''
         if isinstance(defs_bucket_access_logs_config, dict):
             defs_bucket_access_logs_config = ServerlessClamscanLoggingProps(**defs_bucket_access_logs_config)
@@ -422,6 +428,8 @@ class ServerlessClamscanProps:
             self._values["on_error"] = on_error
         if on_result is not None:
             self._values["on_result"] = on_result
+        if reserved_concurrency is not None:
+            self._values["reserved_concurrency"] = reserved_concurrency
 
     @builtins.property
     def buckets(self) -> typing.Optional[typing.List[monocdk.aws_s3.Bucket]]:
@@ -458,6 +466,15 @@ class ServerlessClamscanProps:
         result = self._values.get("on_result")
         return typing.cast(typing.Optional[monocdk.aws_lambda.IDestination], result)
 
+    @builtins.property
+    def reserved_concurrency(self) -> typing.Optional[jsii.Number]:
+        '''Optionally set a reserved concurrency for the virus scanning Lambda.
+
+        :see: https://docs.aws.amazon.com/lambda/latest/operatorguide/reserved-concurrency.html
+        '''
+        result = self._values.get("reserved_concurrency")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
